@@ -15,7 +15,7 @@ as_sf <- function(geo, ...) UseMethod("as_sf")
 as_sf.geo_list <- function(geo, ...) {
     if (length(geo$features) == 0L)
         stop("Cannot convert to sf: no data")
-    sf::read_sf(as_json(geo), stringsAsFactors = FALSE)
+    sfread_(as_json(geo), stringsAsFactors = FALSE)
 }
 
 #' @rdname as_sf
@@ -26,7 +26,7 @@ as_sf.mapzen_vector_layer <- function(geo, ...) {
 
     geo <- recalculate_ids(geo)
     geo <- collapse_properties(geo)
-    res <- sf::read_sf(as_json(geo))
+    res <- sfread_(as_json(geo), stringsAsFactors = FALSE)
 
     # polygons that were separated by tile divisions will have the same ids
     # b/c of recalculate_ids. need to union them into a single polygon and
@@ -39,3 +39,13 @@ as_sf.mapzen_vector_layer <- function(geo, ...) {
     res <- dplyr::summarise(res)
     dplyr::ungroup(res)
 }
+
+# note: this is more reliable than counting on sf to recognize that the input
+# string is not a filename
+sfread_ <- function(charstring, ...) {
+    tmp <- tempfile(pattern = "geojson", fileext = ".json")
+    td <- dirname(tmp)
+    if (!dir.exists(td)) dir.create(td)
+    writeLines(charstring, tmp)
+    sf::read_sf(tmp, ...)
+}
